==> ngcsdk-3.43.0-py3-none-any.whl: forge/api/ssh_key.py <==
# Copyright (c) 2022, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from itertools import chain
import json

from ngcbpc.api.pagination import pagination_helper_header_page_reference
from ngcbpc.util.utils import format_org_team

PAGE_SIZE = 100


class SSHKeyAPI:
    def __init__(self, connection):
        self.connection = connection

    @staticmethod
    def _get_ssh_key_endpoint(org_name=None, team_name=None):
        org_team = format_org_team(org_name, team_name, plural_form=False)
        return "/".join(["v2", org_team, "forge", "sshkey"])

    def list(self, org_name, team_name, target):
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        params = []
        if target:
            params.append(f"query={target}")
        params.append("includeRelation=Tenant")
        params.append("orderBy=UPDATED_DESC")
        params.append(f"pageSize={PAGE_SIZE}")
        query = "?".join([ep, "&".join(params)])
        return chain(
            *[
                res
                for res in pagination_helper_header_page_reference(
                    self.connection, query, org_name=org_name, team_name=team_name, operation_name="list_ssh_key"
                )
                if res
            ]
        )

    def info(self, org_name, team_name, ssh_key_id):
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        url = f"{ep}/{ssh_key_id}"
        resp = self.connection.make_api_request(
            "GET", url, auth_org=org_name, auth_team=team_name, operation_name="ssh_key_info"
        )
        return resp

    def create(
        self,
        org_name,
        team_name,
        tenant,
        name,
        public_key,
        expiration,
    ):
        url = self._get_ssh_key_endpoint(org_name, team_name)
        create_obj = {
            "tenantId": tenant,
            "name": name,
            "publicKey": public_key,
            "expires": expiration.strftime("%Y-%m-%dT%H:%M:%S.%fZ") if expiration else expiration,
        }
        resp = self.connection.make_api_request(
            "POST",
            url,
            auth_org=org_name,
            auth_team=team_name,
            payload=json.dumps(create_obj),
            operation_name="create_ssh_key",
        )
        return resp

    def update(self, org_name, team_name, ssh_key_id, name):
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        url = f"{ep}/{ssh_key_id}"
        update_obj = {
            "name": name,
        }
        resp = self.connection.make_api_request(
            "PATCH",
            url,
            auth_org=org_name,
            auth_team=team_name,
            payload=json.dumps(update_obj),
            operation_name="update_ssh_key",
        )
        return resp

    def remove(self, org_name, team_name, ssh_key_id):
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        url = f"{ep}/{ssh_key_id}"
        resp = self.connection.make_api_request(
            "DELETE",
            url,
            auth_org=org_name,
            auth_team=team_name,
            operation_name="remove_ssh_key",
            json_response=False,
        )
        return resp


class GuestSSHKeyAPI(SSHKeyAPI):
    pass

==> ngcsdk-3.49.0-py3-none-any.whl: forge/api/ssh_key.py <==
# Copyright (c) 2022, NVIDIA CORPORATION.  All rights reserved.
#
# NVIDIA CORPORATION and its licensors retain all intellectual property
# and proprietary rights in and to this software, related documentation
# and any modifications thereto.  Any use, reproduction, disclosure or
# distribution of this software and related documentation without an express
# license agreement from NVIDIA CORPORATION is strictly prohibited.

from itertools import chain
import json

from ngcbpc.api.pagination import pagination_helper_header_page_reference
from ngcbpc.util.utils import format_org_team

PAGE_SIZE = 100


class SSHKeyAPI:  # noqa: D101
    def __init__(self, connection):
        self.connection = connection

    @staticmethod
    def _get_ssh_key_endpoint(org_name=None, team_name=None):
        org_team = format_org_team(org_name, team_name, plural_form=False)
        return "/".join(["v2", org_team, "forge", "sshkey"])

    def list(self, org_name, team_name, target):  # noqa: D102
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        params = []
        if target:
            params.append(f"query={target}")
        params.append("includeRelation=Tenant")
        params.append("orderBy=UPDATED_DESC")
        params.append(f"pageSize={PAGE_SIZE}")
        query = "?".join([ep, "&".join(params)])
        return chain(
            *[
                res
                for res in pagination_helper_header_page_reference(
                    self.connection, query, org_name=org_name, team_name=team_name, operation_name="list_ssh_key"
                )
                if res
            ]
        )

    def info(self, org_name, team_name, ssh_key_id):  # noqa: D102
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        url = f"{ep}/{ssh_key_id}"
        resp = self.connection.make_api_request(
            "GET", url, auth_org=org_name, auth_team=team_name, operation_name="ssh_key_info"
        )
        return resp

    def create(  # noqa: D102
        self,
        org_name,
        team_name,
        tenant,
        name,
        public_key,
        expiration,
    ):
        url = self._get_ssh_key_endpoint(org_name, team_name)
        create_obj = {
            "tenantId": tenant,
            "name": name,
            "publicKey": public_key,
            "expires": expiration.strftime("%Y-%m-%dT%H:%M:%S.%fZ") if expiration else expiration,
        }
        resp = self.connection.make_api_request(
            "POST",
            url,
            auth_org=org_name,
            auth_team=team_name,
            payload=json.dumps(create_obj),
            operation_name="create_ssh_key",
        )
        return resp

    def update(self, org_name, team_name, ssh_key_id, name):  # noqa: D102
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        url = f"{ep}/{ssh_key_id}"
        update_obj = {
            "name": name,
        }
        resp = self.connection.make_api_request(
            "PATCH",
            url,
            auth_org=org_name,
            auth_team=team_name,
            payload=json.dumps(update_obj),
            operation_name="update_ssh_key",
        )
        return resp

    def remove(self, org_name, team_name, ssh_key_id):  # noqa: D102
        ep = self._get_ssh_key_endpoint(org_name, team_name)
        url = f"{ep}/{ssh_key_id}"
        resp = self.connection.make_api_request(
            "DELETE",
            url,
            auth_org=org_name,
            auth_team=team_name,
            operation_name="remove_ssh_key",
            json_response=False,
        )
        return resp


class GuestSSHKeyAPI(SSHKeyAPI):  # noqa: D101
    pass
